Developers guide
================

.. todo::

    Everything developers need to know to get a dev environment running,
    run tests, modify code and submit a successful PR.

    Currently most of this information lives on the wiki. 

    * https://github.com/mapbox/rasterio/wiki/Development-Guide
    * https://github.com/mapbox/rasterio/wiki/Exposing-GDAL-Functionality
    * https://github.com/mapbox/rasterio/wiki/Cython-and-GDAL

    The long term goal is to consolidate into this document.
